==> spice-js-1.1.17.tgz: package/cli/commands/init.js <==
var exec = require('child-process-promise').exec;
var spawn = require('child-process-promise').spawn;
var status = require('../lib/status');
var program = null;
function action(project_name, options) {
    try{
        console.log(`Creating ${project_name}`);
        clone_repo(options.template, project_name)
            .then(function(result){
                "use strict";
                install_packages(options.template, project_name)
            })
            .catch(function(error){
                "use strict";
                throw new Error(error.stack);
            })
    }catch(e){
        console.log(e.stack);
    }
}

function install_packages(template, project_name){
    status.start();
    console.log('Installing Packages');
    let promise = spawn('npm', ['install'], {cwd: project_name});
    let childProcess = promise.childProcess;

    childProcess.stdout.on('data', function (data) {
        console.log(data.toString());
    });
    childProcess.stderr.on('data', function (data) {
        console.log(data.toString());
    });

    promise
        .then(function () {
            console.log('Done installing');
            status.stop();
        })
        .catch(function (err) {
            console.error(err);
            status.stop();
        });
}

function clone_repo(template, project_name){
    return new Promise(function(resolve, reject){
        status.start();
        console.log('Cloning Packages');
        let promise = spawn('git', ['clone', 'git@bitbucket.org:sonover/spice_sample_with_auth_spa.git', `${project_name}`]);
        let childProcess = promise.childProcess;

        childProcess.stdout.on('data', function (data) {
            console.log(data.toString());
        });
        childProcess.stderr.on('data', function (data) {
            console.log(data.toString());
        });

        promise
            .then(function () {
                console.log('Done cloning');
                status.stop();
                exec(`cd ${project_name} && rm -fr .git && mkdir storage && cd storage && mkdir logs`);
                resolve('done');
            })
            .catch(function (err) {
                console.error(err);
                status.stop();
                reject(err);
            });
    });
}

function command(prog) {
    'use strict';
    program = prog;
    program
        .version('0.0.1')
        .command('init <project_name>')
        .description('Create New Spice.js Project')
        .action(action)
}

module.exports = {
    command: command,
    action: action
};

==> spice-js-2.0.9.tgz: package/cli/commands/init.js <==
var exec = require('child-process-promise').exec;
var spawn = require('child-process-promise').spawn;
var status = require('../lib/status');
let  path = require('path');
var program = null;

function action(project_name, options) {
    try {
        console.log(`Creating ${project_name}`);
        clone_repo(options.template, project_name)
            .then(function (result) {
                "use strict";
                install_packages(options.template, project_name)
            })
            .catch(function (error) {
                "use strict";
                throw new Error(error.stack);
            })
    } catch (e) {
        console.log(e.stack);
    }
}

function install_packages(template, project_name) {
    status.start();
    console.log('Installing Packages');
    let promise = spawn('npm', ['install'], { cwd: project_name });
    let childProcess = promise.childProcess;

    childProcess.stdout.on('data', function (data) {
        console.log(data.toString());
    });
    childProcess.stderr.on('data', function (data) {
        console.log(data.toString());
    });

    promise
        .then(function () {
            console.log('Done installing');
            status.stop();
        })
        .catch(function (err) {
            console.error(err);
            status.stop();
        });
}

function clone_repo(template, project_name) {
    return new Promise(function (resolve, reject) {
        status.start();
        console.log('Cloning Packages');
        let templatePath = path.join(__dirname, '/../make_templates/spice_template');
        let promise = spawn('cp', ['-r', templatePath, `${project_name}`]);

        let childProcess = promise.childProcess;

        childProcess.stdout.on('data', function (data) {
            console.log(data.toString());
        });
        childProcess.stderr.on('data', function (data) {
            console.log(data.toString());
        });
        //remove the .git
        promise
            .then(function () {
                console.log('Done cloning');
                status.stop();
                exec(`cd ${project_name} && rm -fr .git && mkdir storage && cd storage && mkdir logs`);
                resolve('done');
            })
            .catch(function (err) {
                console.error(err);
                status.stop();
                reject(err);
            });
    });
}

function command(prog) {
    'use strict';
    program = prog;
    program
        .version('0.0.1')
        .command('init <project_name>')
        .description('Create New Spice.js Project')
        .action(action)
}

module.exports = {
    command: command,
    action: action
};
